function [header_out, perr] = sp3c_parse_header(Yf_header)
// zerlegt den Header einer SP3-Datei version C  (lines 1-22)
//
// in :   Yf_header - Vektor mit Strings der eingelesenen Datei
//
// out:  header_out .date: [yyyy,mm,dd,hh,mm,ss.ss]  -  date of file
//                          .epochs: [int]  -  number of epoches
//                          .orbit_type: [int]  1=FIT, 2=EXT, 3=BCT, 4=HLM, 0= calculated or not defined
//                          .epoch_interval: [int]  - seconds between epoches
//                          .gpsweek: [int, int]  -  date of file in [gpsweek, seconds of week]
//                          .svnumber: [int]  -  number of SVs contained
//                          .satnames: [nx1 strings]  -  identifier of SVs contained
//                          .accuracy: [nx1 float]  -  accuracy of postion of SVs contained
//                          .file_type: [string]  -  "G", "R", "E", "L", "M"
//                          .time_sys: [string]  -  "GPS" , "GLO", "GAL", "TAI", "UTC"
//                          .base_values: [float]  -  Base of Pos (or Velocity) [mm or 10^-4 mm/sec]
//                          .base_clkrate: [float]  -  Base for clock(P) or clockrate(V) [psec or 10^-4 psec/sec]
//                          .comment: [4x1 string]
//                          .hash: 0           not used [TODO]
//        perr     - parse errors [strings]
// Copyright (c) area7/Christof Schulze  2007-2011
// -------------------------------------------------------------
// private functions: none
// -------------------------------------------------------------
%debug=1

// Ouput variables initialisation (not found in input variables)
  header_out=[]; perr=[];
  header=struct();
  
  if (exists('%debug','local')==1) then
    timer();
    //mprintf('\t * SP3 * Header: %s\n', Yf_header);
  end;

line = Yf_header(1);                                  // line -   1
  [header.date, err] = sp3_parse_date(part(line,4:31));
  // Date [yyyy,mm,dd,hh,ss]
  
  header.epochs = evstr(part(line,33:39));           // Number of Epochs in File
  if err<>0 then
    perr = [perr; sprintf('Parseerror line 1, date (%i)', err)];
    return;
  end;
  header.orbit_type = part(line, 53:55);              // Orbit type
  // 1=FIT (fitted), 2=EXT (extrapolated or predicted),
  // 3=BCT (broadcast), and 4=HLM (fitted after applying a Helmert transformation)
  // 0= calculated or not defined
  if header.orbit_type=="FIT" then
    header.orbit_type=1;
  elseif header.orbit_type=="EXT" then
    header.orbit_type=2;
  elseif header.orbit_type=="BCT" then
    header.orbit_type=3;
  elseif header.orbit_type=="HLM" then
    header.orbit_type=4;
  else
    header.orbit_type=0;
  end;
  
line = Yf_header(2);                                  // Line ---   2
  if ('##' <> part(line,1:2) ) then
    perr=[perr; "Parseerror line 2"];
    return;
  end;
  header.epoch_interval = evstr(part(line,25:38));   // Epoch Interval (sec)
  gpsweek = evstr(part(line,4:7));                          // GPS Week
  gpssecs = evstr(part(line,9:23));                         // Seconds of Week
  date_mjd   = evstr(part(line,40:44));                   // Mod Jul Day
  date_mjd = date_mjd + evstr(part(line,46:60));  // Fractional Day
  
  // check all transformed dates and save diverences for later analysis
  div1 = (date_mjd - (dat_cal2mjd(header.date')))*24*3600;
  if abs(div1)>0.5 then
    perr=[perr; "possible Parseerror ''date_mjd''"];
  end;
  [_cal_gpsw, _cal_gpss] = dat_cal2gpsweek(header.date');
  if ((gpsweek<>_cal_gpsw)) then
    perr=[perr; "possible Parseerror ''gpsweek''"];
  end;
  if abs(gpssecs-_cal_gpss)>0.5 then
    perr=[perr; "possible Parseerror ''gpssecs''"];
  end;
  
  header.gpsweek = [gpsweek,gpssecs];
  
line = Yf_header(3:7);                                // Line ---   3-7 (Satnames)
  header.svnumber    = evstr(part(line(1),5:6));      // Number of Sats
  
  i = find(~(part(line,1:2)=='+ '));                         // check Zeilenanfang
  if i~=[] then
    perr=[perr; sprintf("Parseerror lines %s", format_linevec(i+2) )];
    return;
  end;
 
  satstrs = [];
  for i=1:5 do
    tmpsats = stripblanks(strsplit(line(i),[9:3:60-2]));
    satstrs = [satstrs; tmpsats(2 : size(tmpsats,1))];
  end;
  satnames = satstrs(find(strcmp(satstrs,'0')));
  if (exists('%debug')==1) then
    mprintf('\t ** sp3(3-7) sats: %s\n', format_linevec(satnames'));
  end;
  if (size(satnames,1)<>header.svnumber) then perr=[perr; "Parseerror line 3-7"]; return; end;
  // "Gnn" - GPS, "Rnn" - GLONASS, "Lnn" - Low-Earth Orbiting (LEO),  "Enn" - Galileo
  header.satnames = satnames;
  
line = Yf_header(8:12);                               // Line ---  8-12 (Accuracy)
  i = find(~(part(line,1:2)=='++'));                      // check Zeilenanfang
  if i~=[] then
    perr=[perr; sprintf("Parseerror lines %s", format_linevec(i+7) )];
    return;
  end;
  
  accstrs = [];
  for i=1:5 do
    tmpaccs = stripblanks(strsplit(line(i),[9:3:60-2]));
    accstrs = [accstrs; tmpaccs(2 : size(tmpaccs,1))];
  end;
  tmp_acc = 2^eval(accstrs(find(strcmp(accstrs,'0'))));
  if (size(tmp_acc,1)<>header.svnumber) then perr=[perr; "Parseerror line 8-12"]; return; end;
  if (exists('%debug')==1) then
    mprintf('\t ** sp3(8-12) accs[mm]: %s\n', format_linevec(tmp_acc'));
  end;
  header.accuracy = 2^eval(accstrs(1:header.svnumber));
  
line = Yf_header(13);                                 // Line ---  13
  if ('%c' <> part(line,1:2) ) then
    perr=[perr; sprintf("Parseerror lines 13")];
    return;
  end;
  header.file_type = stripblanks(part(line,4:5));     // Filetype
  file_type_allowed=["G", "R", "E", "L", "M"];
  // "G " - GPS only, "R " - GLONASS only, "E " - Galileo only, "L " - LEO only,
  // "M " - mixed,
  if ~find(header.file_type==file_type_allowed) then
    perr=[perr; sprintf("Parseerror line 13, only %s allowed", format_linevec(file_type_allowed))]; 
  end;
  
  header.time_sys  = part(line, 10:12);               // Time system (GPS)
  time_sys_allowed=["GPS", "GLO", "GAL", "TAI", "UTC"];
  // "GPS" - GPS Time, "GLO" - GLONASS UTC time system,
  // "GAL" - Galileo system time, "TAI" - International Atomic Time,
  // "UTC" - Coordinated Universal Time
  if ~find(header.time_sys==time_sys_allowed) then
    perr=[perr; sprintf("Parseerror line 13, only %s allowed", format_linevec(time_sys_allowed))]; 
  end;
  
  if ('%c' <> part(Yf_header(14),1:2) ) then          // Line ---  14 (unuesd)
    perr=[perr; sprintf("Parseerror lines 14")];
    return;
  end;
  
line = Yf_header(15);                                        // Line ---  15
  if ('%f' <> part(line,1:2) ) then
    perr=[perr; sprintf("Parseerror lines 15")];
    return;
  end;
  header.base_values = evstr(part(line,4:13));
  header.base_clkrate= evstr(part(line,15:26));

  if ('%f' <> part(Yf_header(16),1:2) ) then          // Line ---  16 (unused)
    perr=[perr; sprintf("Parseerror lines 16")];
    return;
  end;     
  if ('%i' <> part(Yf_header(17),1:2) ) then          // Line ---  17 (unused)
    perr=[perr; sprintf("Parseerror lines 17")];
    return;
  end;
  if ('%i' <> part(Yf_header(18),1:2) ) then          // Line ---  18 (unused)
    perr=[perr; sprintf("Parseerror lines 18")];
    return;
  end;
  
line = Yf_header(19:22);                              // Line --- 19-22 (Comment)
  i = find(~(part(line,1:3)=='/* '));                 // check Zeilenanfang
  if i~=[] then
    perr=[perr; sprintf("Parseerror lines %s", format_linevec(i+18) )];
    return;
  end;
  header.comment = stripblanks(part(line, 4:60));

  // check header.file_type with header.satnames
  if (header.file_type<>'M') then
    if (exists('%debug','local')==1) then
      mprintf('\t * SP3 * File ist not Mixed.\n');
    end;
    if ~and(part(header.satnames,1)==header.file_type) then
      perr=[perr; sprintf("Parserror SVnames are not specified by filetype.")];
    end;
    
  else
    if (exists('%debug','local')==1) then
      mprintf('\t * SP3 * File Mixed (Satnames are not checked!).\n');
    end;   
    // [TODO]
  end;
  
  header.hash=0; // [TODO]
  
  header_out = header;
  
  if (exists('%debug','local')==1) then
    mprintf('\t * SP3 * header parsed in %f(ckls).\n', timer());
    disp(perr);
  end;
  
endfunction;